Modules
- cli
- Shared helpers for thin package-surface CLI adapters.
- landscape
- server
- Shared helpers for local package-surface HTTP adapters.
Structs
- Artifact
Id - Diagnostic
- Diagnostic
Code - JobId
- Operation
Id - Operation
Metadata - Package
Surface - Runtime
Capabilities - Runtime
Requirement - Surface
Artifact Expectation - Surface
Error - Surface
Execution Plan - Surface
Operation - Surface
Request - Surface
Response
Enums
Functions
- attach_
landscape_ contract - describe_
surface_ response - Builds the standard
describeresponse without changing the sharedSurfaceResponseJSON shape. - ensure_
structured_ surface_ value - Adds the common package-surface UI fields to a result value when they are missing, while preserving every existing top-level domain field.
- landscape_
operation_ contract_ value - operation_
category - parse_
surface_ error - parse_
surface_ input - require_
non_ empty - structured_
operation_ response - Builds a structured response for an operation listed in a package surface.
- structured_
surface_ response - Builds a successful package-surface response using
structured_surface_value. - structured_
surface_ value - Builds a package-surface value with standard human-readable metadata while preserving object fields from the concrete operation result at the top level.
- surface_
execution_ plan_ value - surface_
input_ schema - surface_
operation - Builds the standard package-surface operation metadata used by library crates and transport adapters.
- surface_
operation_ with_ execution_ plan - surface_
operation_ with_ landscape - surface_
output_ schema - surface_
response - Builds a successful surface response with empty diagnostics and artifacts.
- validate_
matching_ lengths - validate_
max_ items