pub fn describe_surface_response(
surface: &PackageSurface,
request: SurfaceRequest,
) -> SurfaceResponseExpand description
Builds the standard describe response without changing the shared
SurfaceResponse JSON shape.
pub fn describe_surface_response(
surface: &PackageSurface,
request: SurfaceRequest,
) -> SurfaceResponseBuilds the standard describe response without changing the shared
SurfaceResponse JSON shape.